@@ -60,6 +60,7 @@ def pi_header(arguments):
 def user_row(row, row_previous, arguments):
     """ Return user row """
     table_row = []
+    row['resource_type'] = row['resource_type'].replace('Legacy Normalized Core Hours', 'Legacy NCH')
     if row['pid'] == row_previous['pid']:
         table_row.append('')
     else:
@@ -82,6 +83,7 @@ def user_row(row, row_previous, arguments):
 def pi_row(row, arguments, row_previous):
     """ Return pi row """
     # total = [project['total'] for project in jsonout['me'] if project['pid'] == row['pid']][0]
+    row['resource_type'] = row['resource_type'].replace('Legacy Normalized Core Hours', 'Legacy NCH')
     table_row = []
     table_row.append(row['pid'] if row['pid'] != row_previous['pid'] else '')
     table_row.append(row['resource_type'])
@@ -123,7 +125,7 @@ Resource type: Kind of resource eg. Barbora CPU, Karolina GPU,...
 """ % (TABLE_ME_TITLE, TABLE_ME_AS_PI_TITLE),
                                      formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('-p', '--percent', action='store_true',
-                        help="""show values in percentage. Projects with unlimited resources are not displayed""")
+                        help="""Show values in percentage. Projects with unlimited resources are not displayed""")
     # parser.add_argument('-u', '--unit', action='store', help='unit', default='real',
     #                     choices=['perc', 'real', 'both'])
     parser.add_argument('-a', '--all', action='store_true',
