@@ -25,11 +25,11 @@ def motd_categories(slug):
                   {'name': "Service recovered up",        'slug': "service-recovered-up",        'color': "green",   'color_code':"\033[0;32m"},
                   {'name': "Critical service down",       'slug': "critical-service-down",       'color': "red",     'color_code':"\033[1;31m"},
                   {'name': "Service hard down",           'slug': "service-hard-down",           'color': "red",     'color_code':"\033[0;31m"},
-                  {'name': "Auxiliary service down",      'slug': "auxiliary-service-down",      'color': "blue",    'color_code':"\033[0;34m"},
-                  {'name': "Planned outage",              'slug': "planned-outage",              'color': "blue",    'color_code':"\033[0;34m" },
-                  {'name': "Service degraded",            'slug': "service-degraded",            'color': "blue",    'color_code':"\033[0;34m"},
-                  {'name': "Notice",                      'slug': "notice",                      'color': "blue",    'color_code':"\033[0;34m"},
-                  {'name': "Important",                   'slug': "important",                   'color': "blue",    'color_code':"\033[0;34m"}]
+                  {'name': "Auxiliary service down",      'slug': "auxiliary-service-down",      'color': "yellow",  'color_code':"\033[0;33m"},
+                  {'name': "Planned outage",              'slug': "planned-outage",              'color': "yellow",  'color_code':"\033[0;33m" },
+                  {'name': "Service degraded",            'slug': "service-degraded",            'color': "yellow",  'color_code':"\033[0;33m"},
+                  {'name': "Notice",                      'slug': "notice",                      'color': "yellow",  'color_code':"\033[0;33m"},
+                  {'name': "Important",                   'slug': "important",                   'color': "yellow",  'color_code':"\033[0;33m"}]
     result = next(row for row in categories if row['slug'] == slug)
     return result
 
@@ -42,32 +42,42 @@ def render_text(jsonout, width):
                           break_long_words=False,
                           break_on_hyphens=False)
     for item in jsonout:
+        item = item[0]
         updated = True
         category_name = motd_categories(item['category'])
-        print >> sys.stdout, category_name['color_code']
-        print >> sys.stdout, category_name['name'].center(width).encode('utf-8')
+        print (category_name['color_code'])
+        # print >> sys.stdout, category_name['name'].center(width).encode('utf-8')
         mysearch = re.search(r'^(.*)\s(\([\d-]*\sto\s[\d-]*\)$)', item['title'])
         if mysearch:
             for title_line in wrapper.wrap(mysearch.group(1)):
-                print >> sys.stdout, title_line.center(width).encode('utf-8')
-            print >> sys.stdout, mysearch.group(2).center(width).encode('utf-8')
+                print (title_line.center(width).encode('utf-8'))
+            print (mysearch.group(2).encode('utf-8'))
             updated = False
         else:
-            print >> sys.stdout, item['title'].center(width).encode('utf-8')
+            print ('%s: %s' % (category_name['name'], item['title'].encode('utf-8'))).center(width)
 
         if updated:
-            print >> sys.stdout, ('(%s)' % dateutil.parser.parse(item['updated_at']).strftime("%Y-%m-%d %H:%M:%S")).center(width)
+            print ('Posted: '),
+            print ('(%s)' % dateutil.parser.parse(item['updated_at']).strftime("%Y-%m-%d %H:%M:%S")).rjust(width-len('Posted: '))
         if category_name['name'] == "Planned outage":
-            print >> sys.stdout, ('Outage from:(%s) to:(%s)' % (dateutil.parser.parse(item['dateOutageEfficiency']).strftime("%Y-%m-%d %H:%M:%S"),
-                                  dateutil.parser.parse(item['dateOutageExpiration']).strftime("%Y-%m-%d %H:%M:%S"))).center(width)
-        print >> sys.stdout
+            print ('Outage from: (%s) ' % (dateutil.parser.parse(item['dateOutageEfficiency']).strftime("%Y-%m-%d %H:%M:%S"))),
+            print ('to:(%s)' % dateutil.parser.parse(item['dateOutageExpiration']).strftime("%Y-%m-%d %H:%M:%S")).rjust(width-len('Outage from: (1970-01-01 00:00:00) '))
+            system_string = ""
+            for i in item['system_name']:
+                system_string += i + ", "
+            af_title= "Affected systems: "
+            print ('%s' % af_title),
+            print ('%s ' % system_string[:-2]).rjust(width-len(af_title))   # -2 kvuli odstraneni posledni carky a mezery
+
+
         item['content'] = re.sub(r'(<br ?/?>){1,}',
                                  '\n',
                                  item['messageBody'])
         soup = BeautifulSoup(item['content'], 'html.parser')
+        print('')
         for paragraph in soup.get_text().strip().split('\n'):
             print >> sys.stdout, wrapper.fill(paragraph.strip()).encode('utf-8')
-        print >> sys.stdout, "\033[0m"
+        print ("\033[0m")
 
 def render_html(jsonout, page_template):
     """
